@@ -21,7 +21,6 @@ import sys
 import time
 
 import resultsdb_api
-from six import iteritems
 
 from avocado.core.plugin_interfaces import CLI, ResultEvents, Result
 from avocado.core.settings import settings
@@ -39,18 +38,18 @@ class ResultsdbResultEvent(ResultEvents):
     name = 'resultsdb'
     description = 'Resultsdb result support'
 
-    def __init__(self, args):
+    def __init__(self, config):
         self.rdbapi = None
-        if getattr(args, 'resultsdb_api', None) is not None:
-            self.rdbapi = resultsdb_api.ResultsDBapi(args.resultsdb_api)
+        if config.get('resultsdb_api', None) is not None:
+            self.rdbapi = resultsdb_api.ResultsDBapi(config.get('resultsdb_api'))
 
         self.rdblogs = None
-        if getattr(args, 'resultsdb_logs', None) is not None:
-            self.rdblogs = args.resultsdb_logs
+        if config.get('resultsdb_logs', None) is not None:
+            self.rdblogs = config.get('resultsdb_logs')
 
         self.rdbnote_limit = 0
-        if getattr(args, 'resultsdb_note_limit', None) is not None:
-            self.rdbnote_limit = int(args.resultsdb_note_limit)
+        if config.get('resultsdb_note_limit', None) is not None:
+            self.rdbnote_limit = int(config.get('resultsdb_note_limit'))
 
         self.job_id = None
         self.job_logdir = None
@@ -160,10 +159,11 @@ class ResultsdbResult(Result):
     description = 'Resultsdb result support'
 
     def render(self, result, job):
-        if (getattr(job.args, 'resultsdb_logs', None) is not None and
-                getattr(job.args, 'stdout_claimed_by', None) is None):
+        if (job.config.get('resultsdb_logs', None) is not None and
+                job.config.get('stdout_claimed_by', None) is None):
             log_msg = "JOB URL    : %s/%s"
-            LOG_UI.info(log_msg, job.args.resultsdb_logs, os.path.basename(job.logdir))
+            LOG_UI.info(log_msg, job.config.get('resultsdb_logs',
+                                                os.path.basename(job.logdir)))
 
 
 class ResultsdbCLI(CLI):
@@ -192,29 +192,27 @@ class ResultsdbCLI(CLI):
                             dest='resultsdb_note_limit', default=None,
                             help='Maximum note size limit')
 
-        self.configured = True
-
-    def run(self, args):
-        resultsdb_api_url = getattr(args, 'resultsdb_api', None)
+    def run(self, config):
+        resultsdb_api_url = config.get('resultsdb_api', None)
         if resultsdb_api_url is None:
             resultsdb_api_url = settings.get_value('plugins.resultsdb',
                                                    'api_url',
                                                    default=None)
             if resultsdb_api_url is not None:
-                args.resultsdb_api = resultsdb_api_url
+                config['resultsdb_api'] = resultsdb_api_url
 
-        resultsdb_logs = getattr(args, 'resultsdb_logs', None)
+        resultsdb_logs = config.get('resultsdb_logs', None)
         if resultsdb_logs is None:
             resultsdb_logs = settings.get_value('plugins.resultsdb',
                                                 'logs_url',
                                                 default=None)
             if resultsdb_logs is not None:
-                args.resultsdb_logs = resultsdb_logs
+                config['resultsdb_logs'] = resultsdb_logs
 
-        resultsdb_note_limit = getattr(args, 'resultsdb_note_limit', None)
+        resultsdb_note_limit = config.get('resultsdb_note_limit', None)
         if resultsdb_note_limit is None:
             resultsdb_note_limit = settings.get_value('plugins.resultsdb',
                                                       'note_size_limit',
                                                       default=None)
             if resultsdb_note_limit is not None:
-                args.resultsdb_note_limit = resultsdb_note_limit
+                config['resultsdb_note_limit'] = resultsdb_note_limit
